@@ -20,6 +20,7 @@ static const FFCodec * const codec_list[] = {
     &ff_dxv_encoder,
     &ff_exr_encoder,
     &ff_ffv1_encoder,
+    &ff_ffv1_vulkan_encoder,
     &ff_ffvhuff_encoder,
     &ff_fits_encoder,
     &ff_flashsv_encoder,
@@ -110,8 +111,6 @@ static const FFCodec * const codec_list[] = {
     &ff_opus_encoder,
     &ff_ra_144_encoder,
     &ff_sbc_encoder,
-    &ff_sonic_encoder,
-    &ff_sonic_ls_encoder,
     &ff_truehd_encoder,
     &ff_tta_encoder,
     &ff_vorbis_encoder,
@@ -179,6 +178,7 @@ static const FFCodec * const codec_list[] = {
     &ff_libaom_av1_encoder,
     &ff_libgsm_encoder,
     &ff_libgsm_ms_encoder,
+    &ff_libjxl_anim_encoder,
     &ff_libjxl_encoder,
     &ff_libmp3lame_encoder,
     &ff_libopencore_amrnb_encoder,
@@ -202,6 +202,7 @@ static const FFCodec * const codec_list[] = {
     &ff_av1_qsv_encoder,
     &ff_av1_amf_encoder,
     &ff_av1_vaapi_encoder,
+    &ff_av1_vulkan_encoder,
     &ff_h264_amf_encoder,
     &ff_h264_nvenc_encoder,
     &ff_h264_qsv_encoder,
@@ -233,6 +234,7 @@ static const FFCodec * const codec_list[] = {
     &ff_anm_decoder,
     &ff_ansi_decoder,
     &ff_apng_decoder,
+    &ff_apv_decoder,
     &ff_arbc_decoder,
     &ff_argo_decoder,
     &ff_asv1_decoder,
@@ -394,6 +396,7 @@ static const FFCodec * const codec_list[] = {
     &ff_png_decoder,
     &ff_ppm_decoder,
     &ff_prores_decoder,
+    &ff_prores_raw_decoder,
     &ff_prosumer_decoder,
     &ff_psd_decoder,
     &ff_ptx_decoder,
@@ -415,6 +418,7 @@ static const FFCodec * const codec_list[] = {
     &ff_rv20_decoder,
     &ff_rv30_decoder,
     &ff_rv40_decoder,
+    &ff_rv60_decoder,
     &ff_s302m_decoder,
     &ff_sanm_decoder,
     &ff_scpr_decoder,
@@ -547,6 +551,7 @@ static const FFCodec * const codec_list[] = {
     &ff_flac_decoder,
     &ff_ftr_decoder,
     &ff_g723_1_decoder,
+    &ff_g728_decoder,
     &ff_g729_decoder,
     &ff_gsm_decoder,
     &ff_gsm_ms_decoder,
@@ -692,9 +697,11 @@ static const FFCodec * const codec_list[] = {
     &ff_adpcm_ima_smjpeg_decoder,
     &ff_adpcm_ima_wav_decoder,
     &ff_adpcm_ima_ws_decoder,
+    &ff_adpcm_ima_xbox_decoder,
     &ff_adpcm_ms_decoder,
     &ff_adpcm_mtaf_decoder,
     &ff_adpcm_psx_decoder,
+    &ff_adpcm_sanyo_decoder,
     &ff_adpcm_sbpro_2_decoder,
     &ff_adpcm_sbpro_3_decoder,
     &ff_adpcm_sbpro_4_decoder,
@@ -731,6 +738,7 @@ static const FFCodec * const codec_list[] = {
     &ff_libdav1d_decoder,
     &ff_libgsm_decoder,
     &ff_libgsm_ms_decoder,
+    &ff_libjxl_anim_decoder,
     &ff_libjxl_decoder,
     &ff_libopencore_amrnb_decoder,
     &ff_libopencore_amrwb_decoder,
@@ -747,7 +755,10 @@ static const FFCodec * const codec_list[] = {
     &ff_av1_decoder,
     &ff_av1_cuvid_decoder,
     &ff_av1_qsv_decoder,
+    &ff_av1_amf_decoder,
+    &ff_h264_amf_decoder,
     &ff_h264_cuvid_decoder,
+    &ff_hevc_amf_decoder,
     &ff_hevc_cuvid_decoder,
     &ff_mjpeg_cuvid_decoder,
     &ff_mjpeg_qsv_decoder,
@@ -757,6 +768,7 @@ static const FFCodec * const codec_list[] = {
     &ff_vc1_cuvid_decoder,
     &ff_vp8_cuvid_decoder,
     &ff_vp8_qsv_decoder,
+    &ff_vp9_amf_decoder,
     &ff_vp9_cuvid_decoder,
     &ff_vp9_qsv_decoder,
     &ff_vvc_qsv_decoder,
